==> aws-cdk.aws-neptune-alpha-2.2.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_neptune_alpha_DatabaseInstanceAttributes(p) {
}
function _aws_cdk_aws_neptune_alpha_Endpoint(p) {
}
function _aws_cdk_aws_neptune_alpha_ClusterParameterGroupProps(p) {
}
function _aws_cdk_aws_neptune_alpha_ParameterGroupProps(p) {
}
function _aws_cdk_aws_neptune_alpha_IClusterParameterGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_IParameterGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_ISubnetGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_DatabaseClusterAttributes(p) {
}
function _aws_cdk_aws_neptune_alpha_IDatabaseInstance(p) {
}
function _aws_cdk_aws_neptune_alpha_IDatabaseCluster(p) {
}
function _aws_cdk_aws_neptune_alpha_SubnetGroupProps(p) {
}
function _aws_cdk_aws_neptune_alpha_ParameterGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_ClusterParameterGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_SubnetGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_DatabaseInstanceProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.cluster))
        _aws_cdk_aws_neptune_alpha_IDatabaseCluster(p.cluster);
    if (!visitedObjects.has(p.instanceType))
        _aws_cdk_aws_neptune_alpha_InstanceType(p.instanceType);
    if (!visitedObjects.has(p.parameterGroup))
        _aws_cdk_aws_neptune_alpha_IParameterGroup(p.parameterGroup);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_neptune_alpha_DatabaseInstance(p) {
}
function _aws_cdk_aws_neptune_alpha_DatabaseClusterBase(p) {
}
function _aws_cdk_aws_neptune_alpha_EngineVersion(p) {
}
function _aws_cdk_aws_neptune_alpha_DatabaseCluster(p) {
}
function _aws_cdk_aws_neptune_alpha_DatabaseClusterProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.instanceType))
        _aws_cdk_aws_neptune_alpha_InstanceType(p.instanceType);
    if (!visitedObjects.has(p.associatedRoles))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_iam_IRole(p.associatedRoles);
    if (!visitedObjects.has(p.clusterParameterGroup))
        _aws_cdk_aws_neptune_alpha_IClusterParameterGroup(p.clusterParameterGroup);
    if (!visitedObjects.has(p.engineVersion))
        _aws_cdk_aws_neptune_alpha_EngineVersion(p.engineVersion);
    if (!visitedObjects.has(p.parameterGroup))
        _aws_cdk_aws_neptune_alpha_IParameterGroup(p.parameterGroup);
    if (!visitedObjects.has(p.securityGroups))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ec2_ISecurityGroup(p.securityGroups);
    if (!visitedObjects.has(p.subnetGroup))
        _aws_cdk_aws_neptune_alpha_ISubnetGroup(p.subnetGroup);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_neptune_alpha_InstanceType(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_neptune_alpha_DatabaseInstanceAttributes, _aws_cdk_aws_neptune_alpha_Endpoint, _aws_cdk_aws_neptune_alpha_ClusterParameterGroupProps, _aws_cdk_aws_neptune_alpha_ParameterGroupProps, _aws_cdk_aws_neptune_alpha_IClusterParameterGroup, _aws_cdk_aws_neptune_alpha_IParameterGroup, _aws_cdk_aws_neptune_alpha_ISubnetGroup, _aws_cdk_aws_neptune_alpha_DatabaseClusterAttributes, _aws_cdk_aws_neptune_alpha_IDatabaseInstance, _aws_cdk_aws_neptune_alpha_IDatabaseCluster, _aws_cdk_aws_neptune_alpha_SubnetGroupProps, _aws_cdk_aws_neptune_alpha_ParameterGroup, _aws_cdk_aws_neptune_alpha_ClusterParameterGroup, _aws_cdk_aws_neptune_alpha_SubnetGroup, _aws_cdk_aws_neptune_alpha_DatabaseInstanceProps, _aws_cdk_aws_neptune_alpha_DatabaseInstance, _aws_cdk_aws_neptune_alpha_DatabaseClusterBase, _aws_cdk_aws_neptune_alpha_EngineVersion, _aws_cdk_aws_neptune_alpha_DatabaseCluster, _aws_cdk_aws_neptune_alpha_DatabaseClusterProps, _aws_cdk_aws_neptune_alpha_InstanceType };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-neptune-alpha-2.19.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_neptune_alpha_DatabaseInstanceAttributes(p) {
}
function _aws_cdk_aws_neptune_alpha_Endpoint(p) {
}
function _aws_cdk_aws_neptune_alpha_ClusterParameterGroupProps(p) {
}
function _aws_cdk_aws_neptune_alpha_ParameterGroupProps(p) {
}
function _aws_cdk_aws_neptune_alpha_IClusterParameterGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_IParameterGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_ISubnetGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_DatabaseClusterAttributes(p) {
}
function _aws_cdk_aws_neptune_alpha_IDatabaseInstance(p) {
}
function _aws_cdk_aws_neptune_alpha_IDatabaseCluster(p) {
}
function _aws_cdk_aws_neptune_alpha_SubnetGroupProps(p) {
}
function _aws_cdk_aws_neptune_alpha_ClusterParameterGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_SubnetGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_ParameterGroup(p) {
}
function _aws_cdk_aws_neptune_alpha_DatabaseInstanceProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.cluster))
        _aws_cdk_aws_neptune_alpha_IDatabaseCluster(p.cluster);
    if (!visitedObjects.has(p.instanceType))
        _aws_cdk_aws_neptune_alpha_InstanceType(p.instanceType);
    if (!visitedObjects.has(p.parameterGroup))
        _aws_cdk_aws_neptune_alpha_IParameterGroup(p.parameterGroup);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_neptune_alpha_DatabaseInstance(p) {
}
function _aws_cdk_aws_neptune_alpha_DatabaseClusterBase(p) {
}
function _aws_cdk_aws_neptune_alpha_EngineVersion(p) {
}
function _aws_cdk_aws_neptune_alpha_DatabaseCluster(p) {
}
function _aws_cdk_aws_neptune_alpha_DatabaseClusterProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.instanceType))
        _aws_cdk_aws_neptune_alpha_InstanceType(p.instanceType);
    if (!visitedObjects.has(p.associatedRoles))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_iam_IRole(p.associatedRoles);
    if (!visitedObjects.has(p.clusterParameterGroup))
        _aws_cdk_aws_neptune_alpha_IClusterParameterGroup(p.clusterParameterGroup);
    if (!visitedObjects.has(p.engineVersion))
        _aws_cdk_aws_neptune_alpha_EngineVersion(p.engineVersion);
    if (!visitedObjects.has(p.parameterGroup))
        _aws_cdk_aws_neptune_alpha_IParameterGroup(p.parameterGroup);
    if (!visitedObjects.has(p.securityGroups))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ec2_ISecurityGroup(p.securityGroups);
    if (!visitedObjects.has(p.subnetGroup))
        _aws_cdk_aws_neptune_alpha_ISubnetGroup(p.subnetGroup);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_neptune_alpha_InstanceType(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_neptune_alpha_DatabaseInstanceAttributes, _aws_cdk_aws_neptune_alpha_Endpoint, _aws_cdk_aws_neptune_alpha_ClusterParameterGroupProps, _aws_cdk_aws_neptune_alpha_ParameterGroupProps, _aws_cdk_aws_neptune_alpha_IClusterParameterGroup, _aws_cdk_aws_neptune_alpha_IParameterGroup, _aws_cdk_aws_neptune_alpha_ISubnetGroup, _aws_cdk_aws_neptune_alpha_DatabaseClusterAttributes, _aws_cdk_aws_neptune_alpha_IDatabaseInstance, _aws_cdk_aws_neptune_alpha_IDatabaseCluster, _aws_cdk_aws_neptune_alpha_SubnetGroupProps, _aws_cdk_aws_neptune_alpha_ClusterParameterGroup, _aws_cdk_aws_neptune_alpha_SubnetGroup, _aws_cdk_aws_neptune_alpha_ParameterGroup, _aws_cdk_aws_neptune_alpha_DatabaseInstanceProps, _aws_cdk_aws_neptune_alpha_DatabaseInstance, _aws_cdk_aws_neptune_alpha_DatabaseClusterBase, _aws_cdk_aws_neptune_alpha_EngineVersion, _aws_cdk_aws_neptune_alpha_DatabaseCluster, _aws_cdk_aws_neptune_alpha_DatabaseClusterProps, _aws_cdk_aws_neptune_alpha_InstanceType };
module.exports.DeprecationError = DeprecationError;
